#!/usr/bin/python
# encoding: utf-8


from setuptools import setup, find_packages

setup(
    name="two_num_sum-pkg-Liudongbo",
    version="0.2",
    license="MIT Licence",
 
    url="https://github.com/lwxGitHub123/pip_demo",
    author="liudongbo",
    author_email="350272438@qq.com",
 
    packages=find_packages(),
    include_package_data=True,
    platforms="any",
    install_requires=[]
)


